function [Phim, Phip,h]=FundMatrix(E,A)
    // This funtion find the Laurent Expansion coefficients.
//
// Calling Sequence
//  [Phim, Phip,h]=FundMatrix(E,A)
//
// Parameters
// E: Singular matrix   // single line description of each parameter.
// A: A matrix   // parameter name and description must be 
// Phim: Laurent expansion coefficients for k=1,2,...  k<0   
// Phip: Laurent expansion coefficients for k=1,2,...  k>=0   
// h:    Nilpotence Index 
//
// Description
// This function find the Laurent Expansion coefficients.
// Add an empty comment line to format the text into separate paragraphs.
//
// Programlisting:
//   <programlisting>z = test_fun(x, y)</programlisting>
//
// XML format commands may also be used directly in the text.
// <itemizedlist>
// <listitem>An itemized list is shown here</listitem>
// </itemizedlist>
// The help text for help_from_sci was generated from the head comments section of help_from_sci.sci
// Compare the output from head_comments("help_from_sci") and help("help_from_sci")
// to see more examples on how to write the head comments section.
//
// Examples
//  [Phim, Phip,h]=FundMatrix(E,A) // examples of use
//
// // An empty comment line in the Examples section will add a halt() statement
// // in the demo file test_fun.dem.sce generated by help_from_sci.
// See also
//  help_from_sci
//  help_skeleton
//
// Authors
//  Author name ; should be listed one pr line. Use ";" to separate names from additional information 
// Bibliography
//   Literature references one pr. line

// start of coding after on empty line to mark the end of the head_comments section
    
    [P, Q, n]=pencan(E,A)
    Ee=clean(Q*E*P)
    
    
Aux=size(Ee);Aux=Aux(1);

///....N matrix and Nilpotence Index (h)................

N=Ee(n+1:Aux,n+1:Aux);
Ne=zeros(Aux,Aux);
if norm(N)==0 then
Ne(n+1:Aux,n+1:Aux)=-eye(N);
else
Ne(n+1:Aux,n+1:Aux)=-N^0;
end

    h=1;
Ni=N;
while norm(Ni)>1e-8
    Ni=Ni*N
    h=h+1
     end
//..................................... 

//...... Phi0 and Phi k=1,2,..h-1

J=Ee(1:n,1:n);
AD=zeros(Aux,Aux);
AD(1:n,1:n)=J; // Drazin inverse
Phi0=P*AD*Q;
Phip(:,:,1)=clean(Phi0);
for k=1:Aux-1
    Phip(:,:,k+1)=clean(Phip(:,:,k)*A*Phi0);
end

// Phi-1 and Phi-k  for k=2,1... h

Phi1m=P*Ne*Q;
Phim(:,:,1)=clean(Phi1m);

for k=2:h
 Phim(:,:,k)=clean((-Phi1m*E)^(k-1)*Phi1m);    
end
//Phip=clean(Phip);
//Phim=Phim;

endfunction